.. _kaggle:

.. kaggle-cli documentation master file, created by
   sphinx-quickstart on Thu Jun 26 22:53:21 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

kaggle-cli documentation
========================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   configuration
   competitions
   datasets
   kernels
   models
   model_instances
   model_instances_versions
   tutorials
